# TVM 简介

`TVM`
:   Apache TVM 是一个用于  CPU、GPU 和机器学习加速器（accelerator）的开放源码机器学习编译器框架。它旨在使机器学习工程师在任何硬件后端优化和高效运行计算。

Apache TVM 项目的愿景是为机器学习、编译器和系统架构领域的专家和从业者提供多样化的社区，构建可访问的、可扩展的、自动化的开源框架，为任何硬件平台优化当前和新兴的机器学习模型。TVM 提供以下主要功能：

- 将深度学习模型编译为最小可部署模块。
- 基础设施（Infrastructure），以自动生成和优化具有更好性能的更多后端模型。

:::::{grid} 1 1 1 1

::::{grid-item-card} 性能
编译和最小化运行时（runtime）
::::

::::{grid-item-card} Run Everywhere
CPUs, GPUs, browsers, microcontrollers, FPGAs and more.
+++
Automatically generate and optimize tensor operators on more backends.
::::

::::{grid-item-card} Flexibility
Need support for block sparsity, quantization (1,2,4,8 bit integers, posit), random forests/classical ML, memory planning, MISRA-C compatibility, Python prototyping or all of the above?
+++
TVM’s flexible design enables all of these things and more.
::::

::::{grid-item-card} Ease of Use
Compilation of deep learning models in Keras, MXNet, PyTorch, Tensorflow, CoreML, DarkNet and more. Start using TVM with Python today, build out production stacks using C++, Rust, or Java the next day.
::::
:::::
